@@ -12,6 +12,7 @@ import (
 	"k8s.io/apimachinery/pkg/api/resource"
 
 	api "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
+	"github.com/openshift/elasticsearch-operator/pkg/utils"
 	"github.com/openshift/elasticsearch-operator/test/helpers"
 )
 
@@ -359,13 +360,13 @@ func TestResourcesCommonResourceAndNodeLimitDefined(t *testing.T) {
 
 func TestProxyContainerResourcesDefined(t *testing.T) {
 
-	imageName := "openshift/oauth-proxy:1.1"
+	imageName := "openshift/elasticsearch-proxy:1.1"
 	clusterName := "elasticsearch"
 
 	expectedCPU := resource.MustParse("100m")
 	expectedMemory := resource.MustParse("64Mi")
 
-	proxyContainer, err := newProxyContainer(imageName, clusterName)
+	proxyContainer, err := newProxyContainer(imageName, clusterName, "openshift-logging", LogConfig{})
 	if err != nil {
 		t.Errorf("Failed to populate Proxy container: %v", err)
 	}
@@ -395,17 +396,108 @@ func TestProxyContainerResourcesDefined(t *testing.T) {
 	}
 }
 
+func TestProxyContainerTLSClientAuthDefined(t *testing.T) {
+	imageName := "openshift/elasticsearch-proxy:1.1"
+	clusterName := "elasticsearch"
+
+	proxyContainer, err := newProxyContainer(imageName, clusterName, "openshift-logging", LogConfig{})
+	if err != nil {
+		t.Errorf("Failed to populate Proxy container: %v", err)
+	}
+
+	want := []string{
+		"--tls-cert=/etc/proxy/elasticsearch/logging-es.crt",
+		"--tls-key=/etc/proxy/elasticsearch/logging-es.key",
+		"--tls-client-ca=/etc/proxy/elasticsearch/admin-ca",
+	}
+
+	for _, arg := range want {
+		if !sliceContainsString(proxyContainer.Args, arg) {
+			t.Errorf("Missing tls client auth argument: %s", arg)
+		}
+	}
+
+	wantVolumeMount := v1.VolumeMount{Name: "certificates", MountPath: "/etc/proxy/elasticsearch"}
+
+	hasMount := false
+	for _, vm := range proxyContainer.VolumeMounts {
+		if reflect.DeepEqual(vm, wantVolumeMount) {
+			hasMount = true
+		}
+	}
+
+	if !hasMount {
+		t.Errorf("Missing volume mount for tls client auth PKI: %#v", wantVolumeMount)
+	}
+}
+
+func TestProxyContainerSpec(t *testing.T) {
+	imageName := "openshift/elasticsearch-proxy:1.1"
+	clusterName := "elasticsearch"
+
+	proxyContainer, err := newProxyContainer(imageName, clusterName, "openshift-logging", LogConfig{})
+	if err != nil {
+		t.Errorf("Failed to populate Proxy container: %v", err)
+	}
+
+	wantArgs := []string{
+		"--metrics-listening-address=:60001",
+		"--metrics-tls-cert=/etc/proxy/secrets/tls.crt",
+		"--metrics-tls-key=/etc/proxy/secrets/tls.key",
+		"--auth-admin-role=admin_reader",
+		"--auth-default-role=project_user",
+	}
+
+	for _, arg := range wantArgs {
+		if !sliceContainsString(proxyContainer.Args, arg) {
+			t.Errorf("Missing tls client auth argument: %s", arg)
+		}
+	}
+
+	wantPort := v1.ContainerPort{
+		Name:          "metrics",
+		ContainerPort: 60001,
+		Protocol:      v1.ProtocolTCP,
+	}
+
+	hasPort := false
+	for _, port := range proxyContainer.Ports {
+		if port.Name == wantPort.Name && port.ContainerPort == wantPort.ContainerPort && port.Protocol == wantPort.Protocol {
+			hasPort = true
+		}
+	}
+	if !hasPort {
+		t.Errorf("Missing container port for tls metrics: %#v", wantPort)
+	}
+
+	wantVolumeMount := v1.VolumeMount{
+		Name:      "elasticsearch-metrics",
+		MountPath: "/etc/proxy/secrets",
+	}
+
+	hasMount := false
+	for _, vm := range proxyContainer.VolumeMounts {
+		if reflect.DeepEqual(vm, wantVolumeMount) {
+			hasMount = true
+		}
+	}
+
+	if !hasMount {
+		t.Errorf("Missing volume mount for tls metrics PKI: %#v", wantVolumeMount)
+	}
+}
+
 func TestPodSpecHasTaintTolerations(t *testing.T) {
 
 	expectedTolerations := []v1.Toleration{
-		v1.Toleration{
+		{
 			Key:      "node.kubernetes.io/disk-pressure",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
 		},
 	}
 
-	podTemplateSpec := newPodTemplateSpec("test-node-name", "test-cluster-name", "test-namespace-name", api.ElasticsearchNode{}, api.ElasticsearchNodeSpec{}, map[string]string{}, map[api.ElasticsearchNodeRole]bool{}, nil)
+	podTemplateSpec := newPodTemplateSpec("test-node-name", "test-cluster-name", "test-namespace-name", api.ElasticsearchNode{}, api.ElasticsearchNodeSpec{}, map[string]string{}, map[api.ElasticsearchNodeRole]bool{}, nil, LogConfig{})
 
 	if !reflect.DeepEqual(podTemplateSpec.Spec.Tolerations, expectedTolerations) {
 		t.Errorf("Exp. the tolerations to be %v but was %v", expectedTolerations, podTemplateSpec.Spec.Tolerations)
@@ -428,8 +520,8 @@ func TestPodNodeSelectors(t *testing.T) {
 	if len(podSpec.NodeSelector) != 1 {
 		t.Errorf("Exp. single nodeSelector but %d were found", len(podSpec.NodeSelector))
 	}
-	if podSpec.NodeSelector[OsNodeLabel] != LinuxValue {
-		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", OsNodeLabel, LinuxValue)
+	if podSpec.NodeSelector[utils.OsNodeLabel] != utils.LinuxValue {
+		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", utils.OsNodeLabel, utils.LinuxValue)
 	}
 
 	// Create podSpecTemplate providing some custom node selectors, we expect the PodTemplateSpec.Spec selectors
@@ -442,13 +534,13 @@ func TestPodNodeSelectors(t *testing.T) {
 	if len(podSpec.NodeSelector) != 3 {
 		t.Errorf("Exp. single nodeSelector but %d were found", len(podSpec.NodeSelector))
 	}
-	if podSpec.NodeSelector[OsNodeLabel] != LinuxValue {
-		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", OsNodeLabel, LinuxValue)
+	if podSpec.NodeSelector[utils.OsNodeLabel] != utils.LinuxValue {
+		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", utils.OsNodeLabel, utils.LinuxValue)
 	}
 
 	// Create podSpecTemplate providing node selector with some custom value, we expect the PodTemplateSpec.Spec selector
 	// will override the node selector to linux one.
-	podSpec = preparePodTemplateSpecProvidingNodeSelectors(map[string]string{OsNodeLabel: "foo"}).Spec
+	podSpec = preparePodTemplateSpecProvidingNodeSelectors(map[string]string{utils.OsNodeLabel: "foo"}).Spec
 
 	if podSpec.NodeSelector == nil {
 		t.Errorf("Exp. the nodeSelector to contains the linux allocation selector but was %T", podSpec.NodeSelector)
@@ -456,15 +548,15 @@ func TestPodNodeSelectors(t *testing.T) {
 	if len(podSpec.NodeSelector) != 1 {
 		t.Errorf("Exp. single nodeSelector but %d were found", len(podSpec.NodeSelector))
 	}
-	if podSpec.NodeSelector[OsNodeLabel] != LinuxValue {
-		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", OsNodeLabel, LinuxValue)
+	if podSpec.NodeSelector[utils.OsNodeLabel] != utils.LinuxValue {
+		t.Errorf("Exp. the nodeSelector to contains %s: %s pair", utils.OsNodeLabel, utils.LinuxValue)
 	}
 }
 
 func TestPodDiskToleration(t *testing.T) {
 
 	expectedToleration := []v1.Toleration{
-		v1.Toleration{
+		{
 			Key:      "node.kubernetes.io/disk-pressure",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
@@ -499,7 +591,8 @@ func preparePodTemplateSpecProvidingNodeSelectors(selectors map[string]string) v
 		api.ElasticsearchNodeSpec{},
 		map[string]string{},
 		map[api.ElasticsearchNodeRole]bool{},
-		nil)
+		nil,
+		LogConfig{})
 }
 
 func buildResource(cpuLimit, cpuRequest, memLimit, memRequest resource.Quantity) v1.ResourceRequirements {
@@ -549,10 +642,6 @@ func areResourcesSame(lhs, rhs v1.ResourceRequirements) bool {
 	return reflect.DeepEqual(lhs, rhs)
 }
 
-func areQuantitiesSame(lhs, rhs *resource.Quantity) bool {
-	return lhs.Cmp(*rhs) == 0
-}
-
 func printResource(resource v1.ResourceRequirements) string {
 	pretty, err := json.MarshalIndent(resource, "", "  ")
 	if err != nil {
